import React, { useState, useEffect, useRef } from 'react';
import { useNavigate, useLocation } from 'react-router-dom';
import PropTypes from 'prop-types';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { 
  faBell, 
  faUser, 
  faCog, 
  faSignOutAlt, 
  faChevronDown, 
  faChevronUp,
  faSearch,
  faMoon,
  faSun,
  faQuestionCircle
} from '@fortawesome/free-solid-svg-icons';
import './navbar.css';
import logo from '../assets/logo.png';

const Navbar = ({ 
  user, 
  onLogout, 
  notificationCount = 0,
  unreadMessages = 0,
  onThemeChange,
  currentTheme = 'light'
}) => {
  const navigate = useNavigate();
  const location = useLocation();
  const [showDropdown, setShowDropdown] = useState(false);
  const [showNotifications, setShowNotifications] = useState(false);
  const [searchQuery, setSearchQuery] = useState('');
  const dropdownRef = useRef(null);
  const notificationsRef = useRef(null);
  
  // Close dropdowns when clicking outside
  useEffect(() => {
    const handleClickOutside = (event) => {
      if (dropdownRef.current && !dropdownRef.current.contains(event.target)) {
        setShowDropdown(false);
      }
      if (notificationsRef.current && !notificationsRef.current.contains(event.target)) {
        setShowNotifications(false);
      }
    };

    document.addEventListener('mousedown', handleClickOutside);
    return () => document.removeEventListener('mousedown', handleClickOutside);
  }, []);

  // Close dropdowns when route changes
  useEffect(() => {
    setShowDropdown(false);
    setShowNotifications(false);
  }, [location.pathname]);

  const handleProfileClick = () => {
    if (user?.role) {
      navigate(`/${user.role.toLowerCase()}/profile`);
    }
  };

  const handleLogout = () => {
    setShowDropdown(false);
    onLogout();
  };

  const toggleDropdown = () => {
    setShowDropdown(!showDropdown);
    setShowNotifications(false);
  };

  const toggleNotifications = () => {
    setShowNotifications(!showNotifications);
    setShowDropdown(false);
  };

  const handleSearch = (e) => {
    e.preventDefault();
    if (searchQuery.trim()) {
      navigate(`/search?query=${encodeURIComponent(searchQuery)}`);
      setSearchQuery('');
    }
  };

  const toggleTheme = () => {
    onThemeChange(currentTheme === 'light' ? 'dark' : 'light');
  };

  return (
    <nav className={`navbar ${currentTheme}`}>
      {/* Left Section */}
      <div className="navbar-left">
        <div className="logo-container" onClick={() => navigate('/dashboard')}>
          <img src={logo} alt="Company Logo" className="navbar-logo" />
          <span className="navbar-brand">Priente Software License Dashboard </span>
        </div>
        
        <form className="search-bar" onSubmit={handleSearch}>
          <button type="submit" className="search-button">
            <FontAwesomeIcon icon={faSearch} />
          </button>
          <input
            type="text"
            placeholder="Search licenses, users..."
            value={searchQuery}
            onChange={(e) => setSearchQuery(e.target.value)}
          />
        </form>
      </div>

      {/* Right Section */}
      <div className="navbar-right">
        <div className="nav-icon" onClick={toggleTheme}>
          <FontAwesomeIcon icon={currentTheme === 'light' ? faMoon : faSun} />
        </div>
        
        <div className="nav-icon" onClick={() => navigate('/help')}>
          <FontAwesomeIcon icon={faQuestionCircle} />
        </div>

        <div className="notification-wrapper" ref={notificationsRef}>
          <div 
            className={`notification-icon ${notificationCount > 0 ? 'has-notifications' : ''}`}
            onClick={toggleNotifications}
          >
            <FontAwesomeIcon icon={faBell} />
            {notificationCount > 0 && (
              <span className="notification-badge">
                {notificationCount > 9 ? '9+' : notificationCount}
              </span>
            )}
          </div>
          
          {showNotifications && (
            <div className="notifications-dropdown">
              <div className="notifications-header">
                <h3>Notifications ({notificationCount})</h3>
                <button className="mark-all-read">Mark all as read</button>
              </div>
              <div className="notifications-list">
                {/* Sample notification items */}
                <div className="notification-item unread">
                  <div className="notification-icon">
                    <div className="alert-dot"></div>
                  </div>
                  <div className="notification-content">
                    <p>New license request from John Doe</p>
                    <small>2 minutes ago</small>
                  </div>
                </div>
                <div className="notification-item">
                  <div className="notification-icon"></div>
                  <div className="notification-content">
                    <p>Your subscription will renew soon</p>
                    <small>1 hour ago</small>
                  </div>
                </div>
              </div>
              <div className="notifications-footer">
                <button onClick={() => navigate('/notifications')}>View All</button>
              </div>
            </div>
          )}
        </div>

        <div className="user-dropdown" ref={dropdownRef}>
          <div 
            className="user-profile"
            onClick={toggleDropdown}
          >
            <div className="avatar-container">
              <img 
                src={user?.avatar || 'https://i.pravatar.cc/150?img=3'} 
                alt="User" 
                className="user-avatar" 
              />
              {unreadMessages > 0 && (
                <span className="message-badge">{unreadMessages}</span>
              )}
            </div>
            <div className="user-info">
              <span className="user-name">{user?.name || 'Guest'}</span>
              <span className="user-role">{user?.role || 'User'}</span>
            </div>
            <FontAwesomeIcon 
              icon={showDropdown ? faChevronUp : faChevronDown} 
              className="dropdown-chevron"
            />
          </div>

          {showDropdown && (
            <div className="dropdown-menu">
              <div className="dropdown-header">
                <div className="dropdown-avatar">
                  <img 
                    src={user?.avatar || 'https://i.pravatar.cc/150?img=3'} 
                    alt="User" 
                  />
                </div>
                <div className="dropdown-user-info">
                  <h4>{user?.name || 'Guest'}</h4>
                  <p>{user?.email || 'user@example.com'}</p>
                </div>
              </div>
              
              <div className="dropdown-divider"></div>
              
              <div className="dropdown-item" onClick={handleProfileClick}>
                <FontAwesomeIcon icon={faUser} />
                <span>My Profile</span>
              </div>
              
              <div className="dropdown-item" onClick={() => navigate('/settings')}>
                <FontAwesomeIcon icon={faCog} />
                <span>Account Settings</span>
              </div>
              
              <div className="dropdown-divider"></div>
              
              <div className="dropdown-item logout-item" onClick={handleLogout}>
                <FontAwesomeIcon icon={faSignOutAlt} />
                <span>Sign Out</span>
              </div>
            </div>
          )}
        </div>
      </div>
    </nav>
  );
};

Navbar.propTypes = {
  user: PropTypes.shape({
    name: PropTypes.string,
    role: PropTypes.string,
    avatar: PropTypes.string,
    email: PropTypes.string
  }),
  onLogout: PropTypes.func.isRequired,
  notificationCount: PropTypes.number,
  unreadMessages: PropTypes.number,
  onThemeChange: PropTypes.func,
  currentTheme: PropTypes.oneOf(['light', 'dark'])
};

Navbar.defaultProps = {
  notificationCount: 0,
  unreadMessages: 0,
  currentTheme: 'light'
};

export default Navbar;